.. |br| raw:: html

   <br />

RadVel: |br| The Radial Velocity Fitting Toolkit
================================================

Welcome to the documentation for ``radvel``, a Python package for
modeling of radial velocity time series data.

Please cite `Fulton, Petigura, Blunt & Sinukoff (2018)  <http://adsabs.harvard.edu/abs/2018PASP..130d4504F>`_ and the following DOI if you make use of RadVel in your research.

Bug reports and feature requests should be posted to the `GitHub issue tracker <https://github.com/California-Planet-Search/radvel/issues>`_ .

Code contributions are welcome and should be submitted as a pull request. Read `the paper <http://adsabs.harvard.edu/abs/2018PASP..130d4504F>`_ for further details regarding contributions.

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.580821.svg
   :target: https://doi.org/10.5281/zenodo.580821

Contents:

.. toctree::
   :maxdepth: 2

   quickstartcli
   autocorrintro
   tutorials
   api

Indices and tables for Python code
==================================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

